@@ -1,4 +1,4 @@
-from lined.base import Pipeline, mk_multi_func, LayeredPipeline
+from lined.base import Line, Pipeline, mk_multi_func, LayeredPipeline
 from lined.tools import (
     keys_extractor,
     items,
